# Usage example:
#
# Preparation of a large and a small file:
# dd if=/dev/zero of=big_file.bin bs=4096 count=100
# echo 1234 > small_file.bin
#
# Overwrite some bytes in the large file:
# python3 cluster_overwrite.py big_file.bin small_file.bin 10

import argparse

# overwrite bytes
def overwrite_bytes(large_file_path, small_file_path, cluster_number):
  # calculate offset with cluster size
  offset = cluster_number * 4096

  # open large file in binary format for writing
  with open(large_file_path, 'r+b') as large_file:
    # go to the offset
    large_file.seek(offset)

    # read small file in binary format
    with open(small_file_path, 'rb') as small_file:
      # 'data' is of type 'bytes'
      data = small_file.read()

    # write data into the large file
    large_file.write(data)

  print("Finished.")

# read arguments
def main():
  parser = argparse.ArgumentParser(description="Overwrite bytes in a large file with a small file.")
  parser.add_argument('large_file', type=str, help="Path to the large file")
  parser.add_argument('small_file', type=str, help="Path to the small file")
  parser.add_argument('cluster_number', type=int, help="Cluster number, which is multiplied by 4096")

  args = parser.parse_args()

  overwrite_bytes(args.large_file, args.small_file, args.cluster_number)

if __name__ == '__main__':
  main()
